import moment from 'moment-timezone';
import { map } from 'rxjs/operators';
import 'lodash';
import '../../datetime/moment_wrapper.js';
import '../../datetime/rangeutil.js';
import { getTimeZoneInfo } from '../../datetime/timezones.js';
import '../../datetime/formats.js';
import { getTimeZone } from '../../datetime/common.js';
import 'date-fns';
import 'date-fns/add';
import 'date-fns/intervalToDuration';
import { FieldType } from '../../types/dataFrame.js';
import '@grafana/schema';
import '../../types/vector.js';
import '../../types/datasource.js';
import '../../types/legacyEvents.js';
import { DataTransformerID } from './ids.js';

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
const formatTimeTransformer = {
  id: DataTransformerID.formatTime,
  name: "Format Time",
  description: "Set the output format of a time field",
  defaultOptions: { timeField: "", outputFormat: "", useTimezone: true },
  operator: (options) => (source) => source.pipe(
    map((data) => {
      const formatter = createTimeFormatter(options.timeField, options.outputFormat, options.useTimezone);
      if (!Array.isArray(data) || data.length === 0) {
        return data;
      }
      return data.map((frame) => __spreadProps(__spreadValues({}, frame), {
        fields: formatter(frame.fields)
      }));
    })
  )
};
const createTimeFormatter = (timeField, outputFormat, useTimezone) => (fields) => {
  const tz = getTimeZone();
  return fields.map((field) => {
    if (field.name === timeField) {
      const newVals = field.values.map((value) => {
        const date = moment(value);
        if (useTimezone) {
          const info = getTimeZoneInfo(tz, value);
          const realTz = info !== void 0 ? info.ianaName : "UTC";
          return date.tz(realTz).format(outputFormat);
        } else {
          return date.format(outputFormat);
        }
      });
      return __spreadProps(__spreadValues({}, field), {
        type: FieldType.string,
        values: newVals
      });
    }
    return field;
  });
};

export { createTimeFormatter, formatTimeTransformer };
//# sourceMappingURL=formatTime.js.map
